@@ -46,13 +46,13 @@
    to make the BANNER define (used by src/session.c) be a valid SSH
    banner. Release versions have no appended strings and may of course not
    have dashes either. */
-#define LIBSSH2_VERSION                             "1.9.0_DEV"
+#define LIBSSH2_VERSION "1.9.0"
 
 /* The numeric version number is also available "in parts" by using these
    defines: */
-#define LIBSSH2_VERSION_MAJOR                       1
-#define LIBSSH2_VERSION_MINOR                       9
-#define LIBSSH2_VERSION_PATCH                       0
+#define LIBSSH2_VERSION_MAJOR 1
+#define LIBSSH2_VERSION_MINOR 9
+#define LIBSSH2_VERSION_PATCH 0
 
 /* This is the numeric version of the libssh2 version number, meant for easier
    parsing and comparions by programs. The LIBSSH2_VERSION_NUM define will
@@ -69,7 +69,7 @@
    and it is always a greater number in a more recent release. It makes
    comparisons with greater than and less than work.
 */
-#define LIBSSH2_VERSION_NUM                         0x010900
+#define LIBSSH2_VERSION_NUM 0x010900
 
 /*
  * This is the date and time when the full source package was created. The
@@ -80,7 +80,7 @@
  *
  * "Mon Feb 12 11:35:33 UTC 2007"
  */
-#define LIBSSH2_TIMESTAMP "DEV"
+#define LIBSSH2_TIMESTAMP "Thu Jun 20 06:19:26 UTC 2019"
 
 #ifndef RC_INVOKED
 
@@ -756,6 +756,7 @@ LIBSSH2_API int libssh2_channel_setenv_ex(LIBSSH2_CHANNEL *channel,
                                           const char *value,
                                           unsigned int value_len);
 
+
 #define libssh2_channel_setenv(channel, varname, value)                 \
     libssh2_channel_setenv_ex((channel), (varname),                     \
                               (unsigned int)strlen(varname), (value),   \
@@ -792,6 +793,13 @@ LIBSSH2_API int libssh2_channel_x11_req_ex(LIBSSH2_CHANNEL *channel,
 #define libssh2_channel_x11_req(channel, screen_number) \
  libssh2_channel_x11_req_ex((channel), 0, NULL, NULL, (screen_number))
 
+LIBSSH2_API int libssh2_channel_signal_ex(LIBSSH2_CHANNEL *channel,
+                                          const char *signame,
+                                          unsigned int signame_len);
+#define libssh2_channel_signal(channel, signame) \
+ libssh2_channel_signal_ex((channel), signame, (unsigned int)strlen(signame))
+
+
 LIBSSH2_API int libssh2_channel_process_startup(LIBSSH2_CHANNEL *channel,
                                                 const char *request,
                                                 unsigned int request_len,
